vanhees71 | Physics Forums - The Fusion of Science and Community
Description: vanhees71 is a member of Physics Forums - The Fusion of Science and Community. Male, from Frankfurt/Main, Germany

- Forums
  - Search Forums
  - Recent Posts
  - Unanswered Threads
- Videos
- Members
  - Notable Members
  - Current Visitors
  - Recent Activity
  - New Profile Posts
- Insights
- Search

### Log in or Sign up

Dismiss Notice
Join Physics Forums Today!
The friendliest, high quality science and math community on the planet! Everyone who loves science is here!

Joined:
  Jul 16, 2010

Messages:
  8,249

Likes Received:
  2,326

Trophy Points:
  454

Featured Threads:
  1

### Following 27

1. Chestermiller
2. vela
3. mfb
4. jtbell
5. stevendaryl
6. Dr. Courtney

Show All

### Followers 36

1. Demystifier
2. Orodruin
3. aleazk
4. weirdoguy
5. shinobi20
6. davidbenari

Show All

Gender:
  Male

Location:
  Frankfurt/Main, Germany

Occupation:
  Postdoc at Goethe Universtity Frankfurt (Germany)

Badges:

Science Advisor
Insights Author

# vanhees71

Male, from Frankfurt/Main, Germany

- Profile Posts
- Recent Activity
- Postings
- Information
- Featured Threads

- 1. DrDu

     > Lieber Hendrik,
     > kannst Du hierzu was beitragen?
     > Ich finde keinen rechten Grund, warum sich der Impuls als p->p-mv unter Galilei-Boosts transformiert, Lz ->Lz.
     > https://www.physicsforums.com/threads/what-is-the-suitable-unitary-operator-for-a-rotating-frame.780800/

     Nov 26, 2014
     1. Swapnil Das likes this.
     2. Dirac62

        > hi

        Sep 18, 2015
  Show Ignored Content
- Loading...
- Loading...

- ### About

  Gender:
    Male
  Home Page:
    http://fias.uni-frankfurt.de/~hees/
  Location:
    Frankfurt/Main, Germany
  Occupation:
    Postdoc at Goethe Universtity Frankfurt (Germany)
  Educational Background:
    PhD
  Degree in:
    Relativistic Heavy-Ion Physics (Theory)
  Favorite Area of Science:
    Physics/Math
  Classical Music (Piano, Choir)

  ### Interact

  Content:
    - Find all content by vanhees71
    - Find all threads by vanhees71
- Loading...

- Log in with Facebook
- Log in with Twitter

Your name or email address:

Do you already have an account?
  - No, create an account now.
  - Yes, my password is:
  - Forgot your password?

  Stay logged in